@@ -16,11 +16,12 @@
 # Base class for classes, that are used for tab-completion.
 # Used due to deprecated methods since python 2.2.
 
+
 class LMIWrapperBaseObject(object):
     """
-    Base class for all LMI wrapper classes, such as :py:class:`LMINamespace`,
-    :py:class:`LMIClass`, :py:class:`LMIInstanceName`, :py:class:`LMIInstance`,
-    :py:class:`LMIMethod`.
+    Base class for all LMI wrapper classes, such as :py:class:`.LMINamespace`,
+    :py:class:`.LMIClass`, :py:class:`.LMIInstanceName`,
+    :py:class:`.LMIInstance`, :py:class:`.LMIMethod`.
 
     :param LMIConnection conn: connection object
     """
@@ -31,9 +32,9 @@ class LMIWrapperBaseObject(object):
     @property
     def connection(self):
         """
-        Property returning :class:`LMIConnection` object.
+        Property returning :class:`.LMIConnection` object.
 
         :returns: connection object
-        :rtype: :py:class:`LMIConnection`
+        :rtype: :py:class:`.LMIConnection`
         """
         return self._conn
