@@ -17,15 +17,16 @@ import keyword
 import os.path
 import rlcompleter
 
-from LMIReturnValue import LMIReturnValue
-from LMIConstantValues import LMIConstantValues
-from LMINamespace import LMINamespace
-from LMINamespace import LMINamespaceRoot
-from LMIClass import LMIClass
-from LMIInstance import LMIInstance
-from LMIInstanceName import LMIInstanceName
-from LMIMethod import LMIMethod
-from LMIConnection import LMIConnection
+from lmi.shell.LMIReturnValue import LMIReturnValue
+from lmi.shell.LMIConstantValues import LMIConstantValues
+from lmi.shell.LMINamespace import LMINamespace
+from lmi.shell.LMINamespace import LMINamespaceRoot
+from lmi.shell.LMIClass import LMIClass
+from lmi.shell.LMIInstance import LMIInstance
+from lmi.shell.LMIInstanceName import LMIInstanceName
+from lmi.shell.LMIMethod import LMIMethod
+from lmi.shell.LMIConnection import LMIConnection
+
 
 class LMICompleter(rlcompleter.Completer):
     """
@@ -69,48 +70,54 @@ class LMICompleter(rlcompleter.Completer):
         prefix = os.path.commonprefix(names)
         if prefix and prefix != text:
             return [prefix]
-        return names + [" "]
+        return names
 
     def attr_matches(self, text):
         """
         :param string text: expression to complete
-        :returns: list of attributes of a given expression; if the expression is
-            instance of LMI wrapper class, its important properties/attributes/
-            methods/parameters will be added too
+        :returns: list of attributes of a given expression; if the expression
+            is instance of LMI wrapper class, its important
+            properties/attributes/ methods/parameters will be added too
         :rtype: list of strings
         """
-        (expr, attr) = text.rsplit(".", 1)
+        expr, attr = text.rsplit(".", 1)
         if "(" in expr or ")" in expr:
             # Do not evaluate a callable
             return
 
         obj = eval(expr, self.namespace)
-        words = [self._callable_postfix(obj, member) for member in dir(obj) if member[0] != "_"]
+        words = []
         if isinstance(obj, LMINamespace):
             words.extend([cls for cls in obj.classes() if cls[0] != "_"])
+            if isinstance(obj, LMINamespaceRoot):
+                words.extend(obj.namespaces)
         elif isinstance(obj, LMIClass):
-            words.extend([prop + "Values" for prop in obj.valuemap_properties()])
+            words.extend([p + "Values" for p in obj.valuemap_properties()])
         elif isinstance(obj, LMIInstance):
-            words.extend([method + "(" for method in obj.methods()])
+            words.extend([m + "(" for m in obj.methods()])
             words.extend(obj.properties())
         elif isinstance(obj, LMIInstanceName):
+            words.extend([m + "(" for m in obj.methods()])
             words.extend(obj.key_properties())
         elif isinstance(obj, LMIMethod):
-            words.extend([param + "Values" for param in obj.valuemap_parameters()])
+            words.extend([p + "Values" for p in obj.valuemap_parameters()])
         elif isinstance(obj, LMIConstantValues):
             words.extend(obj.values())
         elif isinstance(obj, LMIReturnValue):
             words.extend(obj.properties())
+        words.extend([self._callable_postfix(obj, member)
+                      for member in dir(obj) if member[0] != "_"])
 
         # Search for words, which can complete the current expression.
         names = filter(lambda word: word.startswith(attr), words)
 
-        # Search for common prefix of all available words we currently got. If there
-        # is any, return such completion.
+        # Search for common prefix of all available words we currently got. If
+        # there is any, return such completion.
         prefix = os.path.commonprefix(names)
         if prefix and prefix != attr:
             return ["%s.%s" % (expr, prefix)]
 
-        # Return all the possible completions or an empty list, if there is no completion
-        # available (to prevent rlcompleter to erase the whole text).
+        # Return all the possible completions or an empty list, if there is no
+        # completion available (to prevent rlcompleter to erase the whole
+        # text).
         return names + [" "] if names else []
