@@ -14,10 +14,12 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 import collections
-import pywbem
+
+from lmi.shell.compat import *
 
 _RValue = collections.namedtuple('RValue', ["rval", "rparams", "errorstr"])
 
+
 class LMIReturnValue(_RValue):
     """
     Class representing a return value, which holds 3 main types of attributes:
@@ -34,7 +36,8 @@ class LMIReturnValue(_RValue):
 
     def __new__(self, rval, rparams=None, errorstr=None):
         rparams = rparams if rparams else {}
-        if not isinstance(rparams, pywbem.NocaseDict):
-            rparams = pywbem.NocaseDict(rparams)
+        if not isinstance(rparams, wbem.NocaseDict):
+            rparams = wbem.NocaseDict(rparams)
         errorstr = errorstr if errorstr else ""
-        return _RValue.__new__(self, rval=rval, rparams=rparams, errorstr=errorstr)
+        return _RValue.__new__(
+            self, rval=rval, rparams=rparams, errorstr=errorstr)
