@@ -13,36 +13,40 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-import pywbem
+from lmi.shell.compat import *
+
 
 class LMIClassCacheEntry(object):
     """
-    Class used for storing :py:class:`CIMClass` in :py:class:`LMIShellCache`.
+    Class used for storing :py:class:`wbem.CIMClass` in
+    :py:class:`.LMIShellCache`.
 
-    :param CIMClass cim_class: :py:class:`CIMClass` to cache
+    :param CIMClass cim_class: :py:class:`wbem.CIMClass` to cache
     :param bool full_fetch: True, if class is cached with qualifiers
     """
     def __init__(self, cim_class, full_fetch):
         self.cim_class = cim_class
         self.full_fetch = full_fetch
 
+
 class LMIShellCache(object):
     """
     Class representing a LMIShell cache.
 
     :param bool active: specifies, if the cache is active
     :param list classname_list: list of strings of cached class names
-    :param dictionary class_dict: cached :py:class:`CIMClass` objects, where the key is
-        the class name and value is :class:`CIMClass` object
-    :param dictionary class_superclass_dict: dictionary, where the key is namespace and
-        value is dictionary of classname:superclass
+    :param dictionary class_dict: cached :py:class:`wbem.CIMClass` objects,
+        where the key is the class name and value is :class:`CIMClass` object
+    :param dictionary class_superclass_dict: dictionary, where the key is
+        namespace and value is dictionary of classname:superclass
     """
     def __init__(self, active=True, classname_dict=None, class_dict=None,
-            class_superclass_dict=None):
-        self._classname_dict = classname_dict if not classname_dict is None else {}
-        self._class_dict = class_dict if not class_dict is None else {}
+                 class_superclass_dict=None):
+        self._classname_dict = classname_dict \
+            if classname_dict is not None else {}
+        self._class_dict = class_dict if class_dict is not None else {}
         self._class_superclass_dict = class_superclass_dict \
-            if not class_superclass_dict is None else {}
+            if class_superclass_dict is not None else {}
         self._active = active
 
     def clear(self):
@@ -53,7 +57,7 @@ class LMIShellCache(object):
         self._class_dict = {}
         self._class_superclass_dict = {}
 
-    def get_classes(self, namespace=pywbem.DEFAULT_NAMESPACE):
+    def get_classes(self, namespace=wbem.DEFAULT_NAMESPACE):
         """
         :param string namespace: namespace storing cached classes
         :returns: list of cached class names or None, if no cached
@@ -61,7 +65,7 @@ class LMIShellCache(object):
         """
         return self._classname_dict.get(namespace, None)
 
-    def set_classes(self, classname_list, namespace=pywbem.DEFAULT_NAMESPACE):
+    def set_classes(self, classname_list, namespace=wbem.DEFAULT_NAMESPACE):
         """
         Stores a new class names' list.
 
@@ -69,26 +73,27 @@ class LMIShellCache(object):
         """
         self._classname_dict[namespace] = classname_list
 
-    def get_class(self, classname, namespace=pywbem.DEFAULT_NAMESPACE):
+    def get_class(self, classname, namespace=wbem.DEFAULT_NAMESPACE):
         """
         :param string classname: cached class name
         :param string namespace: namespace storing cached classes
         :returns: cache object, if proper class name provided, None otherwise
-        :rtype: :py:class:`LMIClassCacheEntry`
+        :rtype: :py:class:`.LMIClassCacheEntry`
         """
-        if not namespace in self._class_dict or \
-                not classname in self._class_dict[namespace]:
+        if namespace not in self._class_dict or \
+                classname not in self._class_dict[namespace]:
             return None
         return self._class_dict[namespace][classname]
 
-    def add_class(self, cim_class, namespace=pywbem.DEFAULT_NAMESPACE, full_fetch=False):
+    def add_class(self, cim_class, namespace=wbem.DEFAULT_NAMESPACE,
+                  full_fetch=False):
         """
-        Stores a new :py:class:`CIMClass` object into the cache.
+        Stores a new :py:class:`wbem.CIMClass` object into the cache.
 
-        :param CIMClass cim_class: :py:class:`CIMClass` object
+        :param CIMClass cim_class: :py:class:`wbem.CIMClass` object
         :param string namespace: namespace storing cached classes
         """
-        if not namespace in self._class_dict:
+        if namespace not in self._class_dict:
             self._class_dict[namespace] = {}
         self._class_dict[namespace][cim_class.classname] = LMIClassCacheEntry(
             cim_class, full_fetch)
@@ -97,11 +102,12 @@ class LMIShellCache(object):
         """
         :param string classname: cached class name
         :param string namespace: namespace name
-        :returns: True, if the cache contains superclass to the given class name; False otherwise
+        :returns: True, if the cache contains superclass to the given class
+            name; False otherwise
         """
-        if not namespace in self._class_superclass_dict:
+        if namespace not in self._class_superclass_dict:
             return False
-        if not classname in self._class_superclass_dict[namespace]:
+        if classname not in self._class_superclass_dict[namespace]:
             return False
         return True
 
@@ -124,7 +130,7 @@ class LMIShellCache(object):
         :param string superclass: super class name to be stored
         :param string namespace: namespace name of the classname
         """
-        if not namespace in self._class_superclass_dict:
+        if namespace not in self._class_superclass_dict:
             self._class_superclass_dict[namespace] = {}
         self._class_superclass_dict[namespace][classname] = superclass
 
